@@ -101,7 +101,6 @@ class SecureFlaskApp(Flask):
         :param configs                     Any additional Flask configs to set/override.
         """
         super().__init__(context)
-
         if cas_url is None:
             raise Exception("CAS url not configured.")
 
@@ -272,8 +271,9 @@ class SecureFlaskApp(Flask):
                 # the decorated route function
                 response = render_template(self.__custom_403) if self.__custom_403 \
                                else jsonify(dict(message="Unauthorized")), 403
-                session["cas-after-login"] = f"{request.path}{_parse_query_string(quoted=False)}"
-                if "cas-object" not in session:
+                current_object = session.get("cas-object")
+                if current_object is None:
+                    session["cas-after-login"] = f"{request.path}{_parse_query_string(quoted=False)}"
                     response = _login(self.__cas_server_url)
                 else:
                     raw_cas = session.get("cas-object")
@@ -399,19 +399,24 @@ def _login(in_cas_url, db_session=None, security_user_table=None):
     :param in_cas_url:      The CAS server url
     :return:                An appropriate redirect url
     """
+    if "logins" in session:
+        session["logins"] = session["logins"] + 1
+    else:
+        session["logins"] = 1
     app_url = f"{request.base_url}{_parse_query_string(quoted=True)}"
     redirect_url = f"{in_cas_url}/cas/login?service={app_url}"
     if "ticket" in request.args:
         session["cas-ticket"] = request.args["ticket"]
 
-    if "cas-ticket" in session:
+    cas_ticket = session.get("cas-ticket")
+    if cas_ticket is not None:
 
         client = caslib.SAMLClient(in_cas_url, app_url)
         cas_response = client.saml_serviceValidate(session["cas-ticket"])
         if cas_response.success:
             session["cas-object"] = CasUser(cas_response.user, cas_response.attributes, db_session,
                                             security_user_table).serialize()
-            redirect_url = session.pop("cas-after-login")
+            redirect_url = session.get("cas-after-login")
         else:
             del session["cas-ticket"]
     return redirect(redirect_url)
